@@ -129,6 +129,36 @@ class TextureScale:
             'Ore': pygame.image.load(os.path.join(base_path, '../assets/hexes/mountain.png')),
             'Sheep': pygame.image.load(os.path.join(base_path, '../assets/hexes/plains.png')),
             'Wood': pygame.image.load(os.path.join(base_path, '../assets/hexes/forest.png')),
+
+            'Wheat1': pygame.image.load(os.path.join(base_path, '../assets/hexes/Wheat/one.png')),
+            'Wheat2': pygame.image.load(os.path.join(base_path, '../assets/hexes/Wheat/two.png')),
+            'Wheat3': pygame.image.load(os.path.join(base_path, '../assets/hexes/Wheat/three.png')),
+            'Wheat4': pygame.image.load(os.path.join(base_path, '../assets/hexes/Wheat/four.png')),
+            'Wheat5': pygame.image.load(os.path.join(base_path, '../assets/hexes/Wheat/five.png')),
+
+            'Brick1': pygame.image.load(os.path.join(base_path, '../assets/hexes/Quarry/one.png')),
+            'Brick2': pygame.image.load(os.path.join(base_path, '../assets/hexes/Quarry/two.png')),
+            'Brick3': pygame.image.load(os.path.join(base_path, '../assets/hexes/Quarry/three.png')),
+            'Brick4': pygame.image.load(os.path.join(base_path, '../assets/hexes/Quarry/four.png')),
+            'Brick5': pygame.image.load(os.path.join(base_path, '../assets/hexes/Quarry/five.png')),
+
+            'Ore1': pygame.image.load(os.path.join(base_path, '../assets/hexes/Mountain/one.png')),
+            'Ore2': pygame.image.load(os.path.join(base_path, '../assets/hexes/Mountain/two.png')),
+            'Ore3': pygame.image.load(os.path.join(base_path, '../assets/hexes/Mountain/three.png')),
+            'Ore4': pygame.image.load(os.path.join(base_path, '../assets/hexes/Mountain/four.png')),
+            'Ore5': pygame.image.load(os.path.join(base_path, '../assets/hexes/Mountain/five.png')),
+
+            'Sheep1': pygame.image.load(os.path.join(base_path, '../assets/hexes/Plains/one.png')),
+            'Sheep2': pygame.image.load(os.path.join(base_path, '../assets/hexes/Plains/two.png')),
+            'Sheep3': pygame.image.load(os.path.join(base_path, '../assets/hexes/Plains/three.png')),
+            'Sheep4': pygame.image.load(os.path.join(base_path, '../assets/hexes/Plains/four.png')),
+            'Sheep5': pygame.image.load(os.path.join(base_path, '../assets/hexes/Plains/five.png')),
+
+            'Wood1': pygame.image.load(os.path.join(base_path, '../assets/hexes/Forest/one.png')),
+            'Wood2': pygame.image.load(os.path.join(base_path, '../assets/hexes/Forest/two.png')),
+            'Wood3': pygame.image.load(os.path.join(base_path, '../assets/hexes/Forest/three.png')),
+            'Wood4': pygame.image.load(os.path.join(base_path, '../assets/hexes/Forest/four.png')),
+            'Wood5': pygame.image.load(os.path.join(base_path, '../assets/hexes/Forest/five.png')),
         }
 
         for key in texture_dictionary:
@@ -212,7 +242,6 @@ class TextureScale:
             'road': pygame.image.load(os.path.join(base_path, '../assets/road.png')),
             'cards': pygame.image.load(os.path.join(base_path, '../assets/cards.png')),
             'star': pygame.image.load(os.path.join(base_path, '../assets/star.png')),
-            'bank': pygame.image.load(os.path.join(base_path, '../assets/bank.png')),
         }
 
         for key in logo_images:
@@ -221,6 +250,13 @@ class TextureScale:
 
         return logo_images
 
+    @staticmethod
+    def scale_bank_logo(logo_size):
+        base_path = os.path.dirname(__file__)
+        image = pygame.image.load(os.path.join(base_path, '../assets/bank.png'))
+        image = pygame.transform.scale(image, logo_size)
+        return image
+
 
 class ButtonResources:
     @staticmethod
