@@ -104,9 +104,13 @@ class card_animation:
         self.total_steps = steps
 
         self.location = init
+        try:
+            self.step_size_x = (self.dest[0] - self.init[0]) / steps / ((fps) / 30)
+            self.step_size_y = (self.dest[1] - self.init[1]) / steps / ((fps) / 30)
+        except ZeroDivisionError: 
+            self.step_size_x = (self.dest[0] - self.init[0]) / steps * 3
+            self.step_size_y = (self.dest[1] - self.init[1]) / steps * 3
 
-        self.step_size_x = (self.dest[0] - self.init[0]) / steps / (fps / 30)
-        self.step_size_y = (self.dest[1] - self.init[1]) / steps / (fps / 30)
 
         self.steps_done = 0
 
