@@ -109,6 +109,7 @@ class GameLobby:
         clock = pygame.time.Clock()
 
         while self.running is True:
+            time_delta = clock.tick(60) / 1000.0
             if self.run_game:
                 self.state = 'game'
                 self.change_state()
@@ -153,12 +154,14 @@ class GameLobby:
                 self.create_notification("A player has left the game")
                 self.player_left = False
             if self.state == "game":
-                self.client_instance.update_frame()
+                try:
+                    self.client_instance.update_frame(time_delta)
+                except TypeError:
+                    pass
                 if not self.client_instance.running and self.winner=='':
                     break
             else:
                 try:
-                    time_delta = clock.tick(60) / 1000.0
                     if self.leave_lobby:
                         self.lobby_code = ''
                         self.player_code = ''
